v1.0.2
=======
- fixed few missing cases where there was no explicit prompt about token being no longer valid
- improved user communication for jobs that library was not able to confirm given the amount of retries and sleep time
- docstrings reformatted to rst in order to generate documentation
- documentation reference added to the general README
- ros_evolution is now communicating warning and details about them i.e. lack of zenodo token in the user profile
- bug fix for functions returning Pandas DataFrame in case there were 0 results, now the dataframe appears empty instead of throwing error
- renamed functions
    * ros_list_funding -> :func:`rohub.ros_list_fundings`
    * list_funding -> :func:`ResearchObject.list_fundings`
    * ros_set_funding (rohub) -> :func:`rohub.ros_add_funding`
    * set_funding (ResearchObject module) -> :func:`ResearchObject.add_funding`
- added functions
    * :func:`rohub.ros_delete_funding`
    * :func:`ResearchObject.delete_funding`
    * :func:`rohub.ros_update_funding`
    * :func:`ResearchObject.update_funding`
    * :func:`rohub.ros_delete_license`
    * :func:`ResearchObject.delete_license`
    * :func:`rohub.show_my_user_profile_details`
    * :func:`admin.delete_external_user`
    * :func:`admin.delete_organization`
- create_doi and publication_services arguments removed from ros_fork
- admin module introduced
- some atttributes constraints removed from ResearchObject and Resource, instead validation happen only when creating new object/updating
- user_id/organization_id arguments removed from respectively: external_user_add, organization_add
- changes to the structure of agents argument for ros_set_authors, ros_set_contributors, ros_set_publishers, ros_set_copyright_holders
- ros_list_fundings is now returning a Pandas DataFrame
- fix to reliability of loading .env file for dev environment (it can now be loaded independent of path where script is executed)
- change to the authentication validation 
- user is no longer forced to login again after 15 minutes, login has to be re-used only when there is no activity for 30 mins